// Generated by CoffeeScript 1.6.3
/*
Copyright 2013 Simon Lydell

This file is part of parse-stack.

parse-stack is free software: you can redistribute it and/or modify it under the terms of the GNU
Lesser General Public License as published by the Free Software Foundation, either version 3 of the
License, or (at your option) any later version.

parse-stack is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without
even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser
General Public License for more details.

You should have received a copy of the GNU Lesser General Public License along with parse-stack. If
not, see <http://www.gnu.org/licenses/>.
*/

var ensureType, formats, newline, parseStack;

formats = [/^\x20+at\x20(?:([^(]+)\x20\()?(.*?)(?::(\d+):(\d+))?\)?$/, /^([^@]*)@(\S*):(\d+)$/];

newline = /\r\n|\r|\n/;

parseStack = function(error) {
  var columnNumber, filepath, format, index, lineNumber, match, name, prelude, stack, stackLine, stackLines, _i, _j, _len, _len1, _ref, _ref1, _results;
  if (typeof error.stack !== "string") {
    return null;
  }
  stack = error.stack;
  prelude = error.toString();
  if (stack.slice(0, prelude.length) === prelude) {
    stack = stack.slice(prelude.length);
  }
  stackLines = stack.split(newline).filter(function(stackLine) {
    return stackLine !== "";
  });
  for (_i = 0, _len = formats.length; _i < _len; _i++) {
    format = formats[_i];
    match = stackLines[0].match(format);
    if (match) {
      break;
    }
  }
  if (!match) {
    throw new Error("Unkown stack trace format:\n" + stack);
  }
  _results = [];
  for (index = _j = 0, _len1 = stackLines.length; _j < _len1; index = ++_j) {
    stackLine = stackLines[index];
    _ref1 = (_ref = stackLine.match(format)) != null ? _ref : [], match = _ref1[0], name = _ref1[1], filepath = _ref1[2], lineNumber = _ref1[3], columnNumber = _ref1[4];
    if (!match) {
      throw new Error("Unknown stack trace formatting on stack line " + (index + 1) + ":\n" + stackLine);
    }
    name = ensureType(String, name);
    filepath = ensureType(String, filepath);
    lineNumber = ensureType(Number, lineNumber);
    columnNumber = ensureType(Number, columnNumber);
    _results.push({
      name: name,
      filepath: filepath,
      lineNumber: lineNumber,
      columnNumber: columnNumber
    });
  }
  return _results;
};

ensureType = function(type, value) {
  if (value) {
    return type(value);
  } else {
    return void 0;
  }
};

module.exports = parseStack;
